<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\AreaAdminRequest;
use Bek\Laundry\Interfaces\AreaRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class AreaAdminController extends AdminController
{
    /**
     * Initialize area controller.
     *
     * @param type AreaRepositoryInterface $area
     *
     * @return type
     */
    public function __construct(AreaRepositoryInterface $area)
    {
        $this->model = $area;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AreaAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.area.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::area.names').' :: ');

        return $this->theme->of('laundry::admin.area.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(AreaAdminRequest $request, $id)
    {
        $area = $this->model->find($id);

        if (empty($area)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.area.new');
        }

        if ($request->wantsJson()) {
            return $area;
        }

        Former::populate($area);

        return view('laundry::admin.area.show', compact('area'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AreaAdminRequest $request)
    {
        $area = $this->model->findOrNew(0);
        Former::populate($area);

        return view('laundry::admin.area.create', compact('area'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AreaAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $area = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::area.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(AreaAdminRequest $request, $id)
    {
        $area = $this->model->find($id);

        Former::populate($area);

        return view('laundry::admin.area.edit', compact('area'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(AreaAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $area = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::area.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AreaAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::area.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
