<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\AreaUserRequest;
use Bek\Laundry\Interfaces\AreaRepositoryInterface;
use Response;
use User;

class AreaUserController extends UserController
{
    /**
     * Initialize area controller.
     *
     * @param type AreaRepositoryInterface $area
     *
     * @return type
     */
    public function __construct(AreaRepositoryInterface $area)
    {
        $this->model = $area;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(AreaUserRequest $request)
    {
        $areas = $this->model->all();

        $this->theme->prependTitle(trans('laundry::area.names').' :: ');

        return $this->theme->of('laundry::user.area.index', compact('areas'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(AreaUserRequest $request, $role, $id)
    {
        $area = $this->model->find($id);

        return $this->theme->of('laundry::user.area.show', compact('area'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AreaUserRequest $request)
    {
        $area = $this->model->findOrNew(0);

        Former::populate($area);

        return $this->theme->of('laundry::user.area.create', compact('area'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AreaUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $area = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::area.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(AreaUserRequest $request, $role, $id)
    {
        $area = $this->model->find($id);

        Former::populate($area);

        return $this->theme->of('laundry::user.area.edit', compact('area'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(AreaUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $area = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::area.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(AreaUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::area.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
