<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\BlockCategoriesAdminRequest;
use Bek\Laundry\Interfaces\BlockCategoriesRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class BlockCategoriesAdminController extends AdminController
{
    /**
     * Initialize block_categories controller.
     *
     * @param type BlockCategoriesRepositoryInterface $block_categories
     *
     * @return type
     */
    public function __construct(BlockCategoriesRepositoryInterface $block_categories)
    {
        $this->model = $block_categories;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(BlockCategoriesAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.block_categories.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::block_categories.names').' :: ');

        return $this->theme->of('laundry::admin.block_categories.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(BlockCategoriesAdminRequest $request, $id)
    {
        $block_categories = $this->model->find($id);

        if (empty($block_categories)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.block_categories.new');
        }

        if ($request->wantsJson()) {
            return $block_categories;
        }

        Former::populate($block_categories);

        return view('laundry::admin.block_categories.show', compact('block_categories'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BlockCategoriesAdminRequest $request)
    {
        $block_categories = $this->model->findOrNew(0);
        Former::populate($block_categories);

        return view('laundry::admin.block_categories.create', compact('block_categories'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BlockCategoriesAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $block_categories = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::block_categories.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(BlockCategoriesAdminRequest $request, $id)
    {
        $block_categories = $this->model->find($id);

        Former::populate($block_categories);

        return view('laundry::admin.block_categories.edit', compact('block_categories'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(BlockCategoriesAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $block_categories = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::block_categories.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BlockCategoriesAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::block_categories.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
