<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\BlockCategoriesUserRequest;
use Bek\Laundry\Interfaces\BlockCategoriesRepositoryInterface;
use Response;
use User;

class BlockCategoriesUserController extends UserController
{
    /**
     * Initialize block_categories controller.
     *
     * @param type BlockCategoriesRepositoryInterface $block_categories
     *
     * @return type
     */
    public function __construct(BlockCategoriesRepositoryInterface $block_categories)
    {
        $this->model = $block_categories;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(BlockCategoriesUserRequest $request)
    {
        $block_categories = $this->model->all();

        $this->theme->prependTitle(trans('laundry::block_categories.names').' :: ');

        return $this->theme->of('laundry::user.block_categories.index', compact('block_categories'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(BlockCategoriesUserRequest $request, $role, $id)
    {
        $block_categories = $this->model->find($id);

        return $this->theme->of('laundry::user.block_categories.show', compact('block_categories'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BlockCategoriesUserRequest $request)
    {
        $block_categories = $this->model->findOrNew(0);

        Former::populate($block_categories);

        return $this->theme->of('laundry::user.block_categories.create', compact('block_categories'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BlockCategoriesUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $block_categories = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::block_categories.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(BlockCategoriesUserRequest $request, $role, $id)
    {
        $block_categories = $this->model->find($id);

        Former::populate($block_categories);

        return $this->theme->of('laundry::user.block_categories.edit', compact('block_categories'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(BlockCategoriesUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $block_categories = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::block_categories.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BlockCategoriesUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::block_categories.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
