<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\BlocksAdminRequest;
use Bek\Laundry\Interfaces\BlocksRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class BlocksAdminController extends AdminController
{
    /**
     * Initialize blocks controller.
     *
     * @param type BlocksRepositoryInterface $blocks
     *
     * @return type
     */
    public function __construct(BlocksRepositoryInterface $blocks)
    {
        $this->model = $blocks;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(BlocksAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.blocks.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::blocks.names').' :: ');

        return $this->theme->of('laundry::admin.blocks.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(BlocksAdminRequest $request, $id)
    {
        $blocks = $this->model->find($id);

        if (empty($blocks)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.blocks.new');
        }

        if ($request->wantsJson()) {
            return $blocks;
        }

        Former::populate($blocks);

        return view('laundry::admin.blocks.show', compact('blocks'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BlocksAdminRequest $request)
    {
        $blocks = $this->model->findOrNew(0);
        Former::populate($blocks);

        return view('laundry::admin.blocks.create', compact('blocks'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BlocksAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $blocks = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::blocks.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(BlocksAdminRequest $request, $id)
    {
        $blocks = $this->model->find($id);

        Former::populate($blocks);

        return view('laundry::admin.blocks.edit', compact('blocks'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(BlocksAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $blocks = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::blocks.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BlocksAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::blocks.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
