<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\BlocksUserRequest;
use Bek\Laundry\Interfaces\BlocksRepositoryInterface;
use Response;
use User;

class BlocksUserController extends UserController
{
    /**
     * Initialize blocks controller.
     *
     * @param type BlocksRepositoryInterface $blocks
     *
     * @return type
     */
    public function __construct(BlocksRepositoryInterface $blocks)
    {
        $this->model = $blocks;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(BlocksUserRequest $request)
    {
        $blocks = $this->model->all();

        $this->theme->prependTitle(trans('laundry::blocks.names').' :: ');

        return $this->theme->of('laundry::user.blocks.index', compact('blocks'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(BlocksUserRequest $request, $role, $id)
    {
        $blocks = $this->model->find($id);

        return $this->theme->of('laundry::user.blocks.show', compact('blocks'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BlocksUserRequest $request)
    {
        $blocks = $this->model->findOrNew(0);

        Former::populate($blocks);

        return $this->theme->of('laundry::user.blocks.create', compact('blocks'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BlocksUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $blocks = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::blocks.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(BlocksUserRequest $request, $role, $id)
    {
        $blocks = $this->model->find($id);

        Former::populate($blocks);

        return $this->theme->of('laundry::user.blocks.edit', compact('blocks'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(BlocksUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $blocks = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::blocks.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BlocksUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::blocks.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
