<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\DiscountsAdminRequest;
use Bek\Laundry\Interfaces\DiscountsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class DiscountsAdminController extends AdminController
{
    /**
     * Initialize discounts controller.
     *
     * @param type DiscountsRepositoryInterface $discounts
     *
     * @return type
     */
    public function __construct(DiscountsRepositoryInterface $discounts)
    {
        $this->model = $discounts;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(DiscountsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.discounts.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::discounts.names').' :: ');

        return $this->theme->of('laundry::admin.discounts.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(DiscountsAdminRequest $request, $id)
    {
        $discounts = $this->model->find($id);

        if (empty($discounts)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.discounts.new');
        }

        if ($request->wantsJson()) {
            return $discounts;
        }

        Former::populate($discounts);

        return view('laundry::admin.discounts.show', compact('discounts'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DiscountsAdminRequest $request)
    {
        $discounts = $this->model->findOrNew(0);
        Former::populate($discounts);

        return view('laundry::admin.discounts.create', compact('discounts'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DiscountsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $discounts = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(DiscountsAdminRequest $request, $id)
    {
        $discounts = $this->model->find($id);

        Former::populate($discounts);

        return view('laundry::admin.discounts.edit', compact('discounts'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(DiscountsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $discounts = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(DiscountsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::discounts.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
