<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\DiscountsUserRequest;
use Bek\Laundry\Interfaces\DiscountsRepositoryInterface;
use Response;
use User;

class DiscountsUserController extends UserController
{
    /**
     * Initialize discounts controller.
     *
     * @param type DiscountsRepositoryInterface $discounts
     *
     * @return type
     */
    public function __construct(DiscountsRepositoryInterface $discounts)
    {
        $this->model = $discounts;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(DiscountsUserRequest $request)
    {
        $discounts = $this->model->all();

        $this->theme->prependTitle(trans('laundry::discounts.names').' :: ');

        return $this->theme->of('laundry::user.discounts.index', compact('discounts'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(DiscountsUserRequest $request, $role, $id)
    {
        $discounts = $this->model->find($id);

        return $this->theme->of('laundry::user.discounts.show', compact('discounts'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DiscountsUserRequest $request)
    {
        $discounts = $this->model->findOrNew(0);

        Former::populate($discounts);

        return $this->theme->of('laundry::user.discounts.create', compact('discounts'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DiscountsUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $discounts = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(DiscountsUserRequest $request, $role, $id)
    {
        $discounts = $this->model->find($id);

        Former::populate($discounts);

        return $this->theme->of('laundry::user.discounts.edit', compact('discounts'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(DiscountsUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $discounts = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(DiscountsUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::discounts.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
