<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\InjursAdminRequest;
use Bek\Laundry\Interfaces\InjursRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class InjursAdminController extends AdminController
{
    /**
     * Initialize injurs controller.
     *
     * @param type InjursRepositoryInterface $injurs
     *
     * @return type
     */
    public function __construct(InjursRepositoryInterface $injurs)
    {
        $this->model = $injurs;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(InjursAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.injurs.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::injurs.names').' :: ');

        return $this->theme->of('laundry::admin.injurs.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(InjursAdminRequest $request, $id)
    {
        $injurs = $this->model->find($id);

        if (empty($injurs)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.injurs.new');
        }

        if ($request->wantsJson()) {
            return $injurs;
        }

        Former::populate($injurs);

        return view('laundry::admin.injurs.show', compact('injurs'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(InjursAdminRequest $request)
    {
        $injurs = $this->model->findOrNew(0);
        Former::populate($injurs);

        return view('laundry::admin.injurs.create', compact('injurs'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InjursAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $injurs = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::injurs.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(InjursAdminRequest $request, $id)
    {
        $injurs = $this->model->find($id);

        Former::populate($injurs);

        return view('laundry::admin.injurs.edit', compact('injurs'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(InjursAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $injurs = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::injurs.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(InjursAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::injurs.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
