<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\InjursUserRequest;
use Bek\Laundry\Interfaces\InjursRepositoryInterface;
use Response;
use User;

class InjursUserController extends UserController
{
    /**
     * Initialize injurs controller.
     *
     * @param type InjursRepositoryInterface $injurs
     *
     * @return type
     */
    public function __construct(InjursRepositoryInterface $injurs)
    {
        $this->model = $injurs;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(InjursUserRequest $request)
    {
        $injurs = $this->model->all();

        $this->theme->prependTitle(trans('laundry::injurs.names').' :: ');

        return $this->theme->of('laundry::user.injurs.index', compact('injurs'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(InjursUserRequest $request, $role, $id)
    {
        $injurs = $this->model->find($id);

        return $this->theme->of('laundry::user.injurs.show', compact('injurs'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(InjursUserRequest $request)
    {
        $injurs = $this->model->findOrNew(0);

        Former::populate($injurs);

        return $this->theme->of('laundry::user.injurs.create', compact('injurs'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InjursUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $injurs = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::injurs.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(InjursUserRequest $request, $role, $id)
    {
        $injurs = $this->model->find($id);

        Former::populate($injurs);

        return $this->theme->of('laundry::user.injurs.edit', compact('injurs'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(InjursUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $injurs = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::injurs.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(InjursUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::injurs.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
