<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\ItemItemsAdminRequest;
use Bek\Laundry\Interfaces\ItemItemsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ItemItemsAdminController extends AdminController
{
    /**
     * Initialize item_items controller.
     *
     * @param type ItemItemsRepositoryInterface $item_items
     *
     * @return type
     */
    public function __construct(ItemItemsRepositoryInterface $item_items)
    {
        $this->model = $item_items;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ItemItemsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.item_items.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::item_items.names').' :: ');

        return $this->theme->of('laundry::admin.item_items.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ItemItemsAdminRequest $request, $id)
    {
        $item_items = $this->model->find($id);

        if (empty($item_items)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.item_items.new');
        }

        if ($request->wantsJson()) {
            return $item_items;
        }

        Former::populate($item_items);

        return view('laundry::admin.item_items.show', compact('item_items'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ItemItemsAdminRequest $request)
    {
        $item_items = $this->model->findOrNew(0);
        Former::populate($item_items);

        return view('laundry::admin.item_items.create', compact('item_items'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ItemItemsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $item_items = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::item_items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ItemItemsAdminRequest $request, $id)
    {
        $item_items = $this->model->find($id);

        Former::populate($item_items);

        return view('laundry::admin.item_items.edit', compact('item_items'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ItemItemsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $item_items = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::item_items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ItemItemsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::item_items.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
