<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\ItemItemsUserRequest;
use Bek\Laundry\Interfaces\ItemItemsRepositoryInterface;
use Response;
use User;

class ItemItemsUserController extends UserController
{
    /**
     * Initialize item_items controller.
     *
     * @param type ItemItemsRepositoryInterface $item_items
     *
     * @return type
     */
    public function __construct(ItemItemsRepositoryInterface $item_items)
    {
        $this->model = $item_items;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ItemItemsUserRequest $request)
    {
        $item_items = $this->model->all();

        $this->theme->prependTitle(trans('laundry::item_items.names').' :: ');

        return $this->theme->of('laundry::user.item_items.index', compact('item_items'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ItemItemsUserRequest $request, $role, $id)
    {
        $item_items = $this->model->find($id);

        return $this->theme->of('laundry::user.item_items.show', compact('item_items'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ItemItemsUserRequest $request)
    {
        $item_items = $this->model->findOrNew(0);

        Former::populate($item_items);

        return $this->theme->of('laundry::user.item_items.create', compact('item_items'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ItemItemsUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $item_items = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::item_items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ItemItemsUserRequest $request, $role, $id)
    {
        $item_items = $this->model->find($id);

        Former::populate($item_items);

        return $this->theme->of('laundry::user.item_items.edit', compact('item_items'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ItemItemsUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $item_items = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::item_items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ItemItemsUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::item_items.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
