<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\ItemTypesAdminRequest;
use Bek\Laundry\Interfaces\ItemTypesRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ItemTypesAdminController extends AdminController
{
    /**
     * Initialize item_types controller.
     *
     * @param type ItemTypesRepositoryInterface $item_types
     *
     * @return type
     */
    public function __construct(ItemTypesRepositoryInterface $item_types)
    {
        $this->model = $item_types;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ItemTypesAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.item_types.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::item_types.names').' :: ');

        return $this->theme->of('laundry::admin.item_types.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ItemTypesAdminRequest $request, $id)
    {
        $item_types = $this->model->find($id);

        if (empty($item_types)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.item_types.new');
        }

        if ($request->wantsJson()) {
            return $item_types;
        }

        Former::populate($item_types);

        return view('laundry::admin.item_types.show', compact('item_types'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ItemTypesAdminRequest $request)
    {
        $item_types = $this->model->findOrNew(0);
        Former::populate($item_types);

        return view('laundry::admin.item_types.create', compact('item_types'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ItemTypesAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $item_types = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::item_types.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ItemTypesAdminRequest $request, $id)
    {
        $item_types = $this->model->find($id);

        Former::populate($item_types);

        return view('laundry::admin.item_types.edit', compact('item_types'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ItemTypesAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $item_types = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::item_types.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ItemTypesAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::item_types.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
