<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\ItemTypesUserRequest;
use Bek\Laundry\Interfaces\ItemTypesRepositoryInterface;
use Response;
use User;

class ItemTypesUserController extends UserController
{
    /**
     * Initialize item_types controller.
     *
     * @param type ItemTypesRepositoryInterface $item_types
     *
     * @return type
     */
    public function __construct(ItemTypesRepositoryInterface $item_types)
    {
        $this->model = $item_types;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ItemTypesUserRequest $request)
    {
        $item_types = $this->model->all();

        $this->theme->prependTitle(trans('laundry::item_types.names').' :: ');

        return $this->theme->of('laundry::user.item_types.index', compact('item_types'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ItemTypesUserRequest $request, $role, $id)
    {
        $item_types = $this->model->find($id);

        return $this->theme->of('laundry::user.item_types.show', compact('item_types'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ItemTypesUserRequest $request)
    {
        $item_types = $this->model->findOrNew(0);

        Former::populate($item_types);

        return $this->theme->of('laundry::user.item_types.create', compact('item_types'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ItemTypesUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $item_types = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::item_types.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ItemTypesUserRequest $request, $role, $id)
    {
        $item_types = $this->model->find($id);

        Former::populate($item_types);

        return $this->theme->of('laundry::user.item_types.edit', compact('item_types'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ItemTypesUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $item_types = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::item_types.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ItemTypesUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::item_types.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
