<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\ItemsAdminRequest;
use Bek\Laundry\Interfaces\ItemsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ItemsAdminController extends AdminController
{
    /**
     * Initialize items controller.
     *
     * @param type ItemsRepositoryInterface $items
     *
     * @return type
     */
    public function __construct(ItemsRepositoryInterface $items)
    {
        $this->model = $items;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ItemsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.items.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::items.names').' :: ');

        return $this->theme->of('laundry::admin.items.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ItemsAdminRequest $request, $id)
    {
        $items = $this->model->find($id);

        if (empty($items)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.items.new');
        }

        if ($request->wantsJson()) {
            return $items;
        }

        Former::populate($items);

        return view('laundry::admin.items.show', compact('items'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ItemsAdminRequest $request)
    {
        $items = $this->model->findOrNew(0);
        Former::populate($items);

        return view('laundry::admin.items.create', compact('items'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ItemsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $items = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ItemsAdminRequest $request, $id)
    {
        $items = $this->model->find($id);

        Former::populate($items);

        return view('laundry::admin.items.edit', compact('items'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ItemsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $items = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ItemsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::items.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
