<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\ItemsUserRequest;
use Bek\Laundry\Interfaces\ItemsRepositoryInterface;
use Response;
use User;

class ItemsUserController extends UserController
{
    /**
     * Initialize items controller.
     *
     * @param type ItemsRepositoryInterface $items
     *
     * @return type
     */
    public function __construct(ItemsRepositoryInterface $items)
    {
        $this->model = $items;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ItemsUserRequest $request)
    {
        $items = $this->model->all();

        $this->theme->prependTitle(trans('laundry::items.names').' :: ');

        return $this->theme->of('laundry::user.items.index', compact('items'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ItemsUserRequest $request, $role, $id)
    {
        $items = $this->model->find($id);

        return $this->theme->of('laundry::user.items.show', compact('items'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ItemsUserRequest $request)
    {
        $items = $this->model->findOrNew(0);

        Former::populate($items);

        return $this->theme->of('laundry::user.items.create', compact('items'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ItemsUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $items = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ItemsUserRequest $request, $role, $id)
    {
        $items = $this->model->find($id);

        Former::populate($items);

        return $this->theme->of('laundry::user.items.edit', compact('items'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ItemsUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $items = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::items.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ItemsUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::items.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
