<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\OptionsAdminRequest;
use Bek\Laundry\Interfaces\OptionsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class OptionsAdminController extends AdminController
{
    /**
     * Initialize options controller.
     *
     * @param type OptionsRepositoryInterface $options
     *
     * @return type
     */
    public function __construct(OptionsRepositoryInterface $options)
    {
        $this->model = $options;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(OptionsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.options.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::options.names').' :: ');

        return $this->theme->of('laundry::admin.options.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(OptionsAdminRequest $request, $id)
    {
        $options = $this->model->find($id);

        if (empty($options)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.options.new');
        }

        if ($request->wantsJson()) {
            return $options;
        }

        Former::populate($options);

        return view('laundry::admin.options.show', compact('options'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OptionsAdminRequest $request)
    {
        $options = $this->model->findOrNew(0);
        Former::populate($options);

        return view('laundry::admin.options.create', compact('options'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OptionsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $options = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::options.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(OptionsAdminRequest $request, $id)
    {
        $options = $this->model->find($id);

        Former::populate($options);

        return view('laundry::admin.options.edit', compact('options'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(OptionsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $options = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::options.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(OptionsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::options.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
