<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\OptionsUserRequest;
use Bek\Laundry\Interfaces\OptionsRepositoryInterface;
use Response;
use User;

class OptionsUserController extends UserController
{
    /**
     * Initialize options controller.
     *
     * @param type OptionsRepositoryInterface $options
     *
     * @return type
     */
    public function __construct(OptionsRepositoryInterface $options)
    {
        $this->model = $options;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(OptionsUserRequest $request)
    {
        $options = $this->model->all();

        $this->theme->prependTitle(trans('laundry::options.names').' :: ');

        return $this->theme->of('laundry::user.options.index', compact('options'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(OptionsUserRequest $request, $role, $id)
    {
        $options = $this->model->find($id);

        return $this->theme->of('laundry::user.options.show', compact('options'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(OptionsUserRequest $request)
    {
        $options = $this->model->findOrNew(0);

        Former::populate($options);

        return $this->theme->of('laundry::user.options.create', compact('options'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OptionsUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $options = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::options.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(OptionsUserRequest $request, $role, $id)
    {
        $options = $this->model->find($id);

        Former::populate($options);

        return $this->theme->of('laundry::user.options.edit', compact('options'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(OptionsUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $options = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::options.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(OptionsUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::options.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
