<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\PaymentMethodsAdminRequest;
use Bek\Laundry\Interfaces\PaymentMethodsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class PaymentMethodsAdminController extends AdminController
{
    /**
     * Initialize payment_methods controller.
     *
     * @param type PaymentMethodsRepositoryInterface $payment_methods
     *
     * @return type
     */
    public function __construct(PaymentMethodsRepositoryInterface $payment_methods)
    {
        $this->model = $payment_methods;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PaymentMethodsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.payment_methods.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::payment_methods.names').' :: ');

        return $this->theme->of('laundry::admin.payment_methods.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PaymentMethodsAdminRequest $request, $id)
    {
        $payment_methods = $this->model->find($id);

        if (empty($payment_methods)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.payment_methods.new');
        }

        if ($request->wantsJson()) {
            return $payment_methods;
        }

        Former::populate($payment_methods);

        return view('laundry::admin.payment_methods.show', compact('payment_methods'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PaymentMethodsAdminRequest $request)
    {
        $payment_methods = $this->model->findOrNew(0);
        Former::populate($payment_methods);

        return view('laundry::admin.payment_methods.create', compact('payment_methods'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PaymentMethodsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $payment_methods = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::payment_methods.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PaymentMethodsAdminRequest $request, $id)
    {
        $payment_methods = $this->model->find($id);

        Former::populate($payment_methods);

        return view('laundry::admin.payment_methods.edit', compact('payment_methods'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PaymentMethodsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $payment_methods = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::payment_methods.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PaymentMethodsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::payment_methods.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
