<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\PaymentMethodsUserRequest;
use Bek\Laundry\Interfaces\PaymentMethodsRepositoryInterface;
use Response;
use User;

class PaymentMethodsUserController extends UserController
{
    /**
     * Initialize payment_methods controller.
     *
     * @param type PaymentMethodsRepositoryInterface $payment_methods
     *
     * @return type
     */
    public function __construct(PaymentMethodsRepositoryInterface $payment_methods)
    {
        $this->model = $payment_methods;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PaymentMethodsUserRequest $request)
    {
        $payment_methods = $this->model->all();

        $this->theme->prependTitle(trans('laundry::payment_methods.names').' :: ');

        return $this->theme->of('laundry::user.payment_methods.index', compact('payment_methods'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PaymentMethodsUserRequest $request, $role, $id)
    {
        $payment_methods = $this->model->find($id);

        return $this->theme->of('laundry::user.payment_methods.show', compact('payment_methods'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PaymentMethodsUserRequest $request)
    {
        $payment_methods = $this->model->findOrNew(0);

        Former::populate($payment_methods);

        return $this->theme->of('laundry::user.payment_methods.create', compact('payment_methods'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PaymentMethodsUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $payment_methods = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::payment_methods.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PaymentMethodsUserRequest $request, $role, $id)
    {
        $payment_methods = $this->model->find($id);

        Former::populate($payment_methods);

        return $this->theme->of('laundry::user.payment_methods.edit', compact('payment_methods'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PaymentMethodsUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $payment_methods = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::payment_methods.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PaymentMethodsUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::payment_methods.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
