<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Bek\Laundry\Http\Requests\UserDiscountsAdminRequest;
use Bek\Laundry\Interfaces\UserDiscountsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class UserDiscountsAdminController extends AdminController
{
    /**
     * Initialize user_discounts controller.
     *
     * @param type UserDiscountsRepositoryInterface $user_discounts
     *
     * @return type
     */
    public function __construct(UserDiscountsRepositoryInterface $user_discounts)
    {
        $this->model = $user_discounts;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(UserDiscountsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('laundry.user_discounts.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('laundry::user_discounts.names').' :: ');

        return $this->theme->of('laundry::admin.user_discounts.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(UserDiscountsAdminRequest $request, $id)
    {
        $user_discounts = $this->model->find($id);

        if (empty($user_discounts)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('laundry::admin.user_discounts.new');
        }

        if ($request->wantsJson()) {
            return $user_discounts;
        }

        Former::populate($user_discounts);

        return view('laundry::admin.user_discounts.show', compact('user_discounts'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(UserDiscountsAdminRequest $request)
    {
        $user_discounts = $this->model->findOrNew(0);
        Former::populate($user_discounts);

        return view('laundry::admin.user_discounts.create', compact('user_discounts'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(UserDiscountsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $user_discounts = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::user_discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(UserDiscountsAdminRequest $request, $id)
    {
        $user_discounts = $this->model->find($id);

        Former::populate($user_discounts);

        return view('laundry::admin.user_discounts.edit', compact('user_discounts'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(UserDiscountsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $user_discounts = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::user_discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(UserDiscountsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::user_discounts.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
