<?php

namespace Bek\Laundry\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Bek\Laundry\Http\Requests\UserDiscountsUserRequest;
use Bek\Laundry\Interfaces\UserDiscountsRepositoryInterface;
use Response;
use User;

class UserDiscountsUserController extends UserController
{
    /**
     * Initialize user_discounts controller.
     *
     * @param type UserDiscountsRepositoryInterface $user_discounts
     *
     * @return type
     */
    public function __construct(UserDiscountsRepositoryInterface $user_discounts)
    {
        $this->model = $user_discounts;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(UserDiscountsUserRequest $request)
    {
        $user_discounts = $this->model->all();

        $this->theme->prependTitle(trans('laundry::user_discounts.names').' :: ');

        return $this->theme->of('laundry::user.user_discounts.index', compact('user_discounts'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(UserDiscountsUserRequest $request, $role, $id)
    {
        $user_discounts = $this->model->find($id);

        return $this->theme->of('laundry::user.user_discounts.show', compact('user_discounts'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(UserDiscountsUserRequest $request)
    {
        $user_discounts = $this->model->findOrNew(0);

        Former::populate($user_discounts);

        return $this->theme->of('laundry::user.user_discounts.create', compact('user_discounts'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(UserDiscountsUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $user_discounts = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('laundry::user_discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(UserDiscountsUserRequest $request, $role, $id)
    {
        $user_discounts = $this->model->find($id);

        Former::populate($user_discounts);

        return $this->theme->of('laundry::user.user_discounts.edit', compact('user_discounts'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(UserDiscountsUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $user_discounts = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('laundry::user_discounts.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(UserDiscountsUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('laundry::user_discounts.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
